amitools Documentation
======================

.. toctree::
    :maxdepth: 2
    :hidden:

    tools/xdftool
    tools/xdfscan
    tools/rdbtool
    tools/romtool

The ``amitools`` are an extensive set of command line tools and Python
libraries that support developers when cross-developing for the Amiga
computer.

Tools
-----

* :doc:`tools/xdftool` - disk image file tool
* :doc:`tools/xdfscan` - scan and validate multiple disk images
* :doc:`tools/rdbtool` - disk partition tool
* :doc:`tools/romtool` - scan and edit Kickstart ROM files

Project Links
-------------

* Source is hosted on `GitHub <https://github.com/cnvogelg/amitools>`_
* CI runs on `GitHub Actions <https://github.com/cnvogelg/amitools/actions>`_
* amitools packages are hosted on `PyPi <https://pypi.org/project/amitools/>`_
* docs are hosted on `ReadTheDocs <https://readthedocs.org/projects/amitools>`_

Release Info
------------

* Version |version|
* Release |release|
